<?php

/**
 * @file
 * Contains \Drupal\page_title_views\Plugin\views\display_extender\PageTitleDisplayExtender.
 */

namespace Drupal\page_title_views\Plugin\views\display_extender;

use Drupal\views\Plugin\views\display_extender\DisplayExtenderPluginBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Page title display extender plugin.
 *
 * @ingroup views_display_extender_plugins
 *
 * @ViewsDisplayExtender(
 *   id = "page_title_display_extender",
 *   title = @Translation("Page title display extender"),
 *   help = @Translation("Page title settings for this view."),
 *   no_ui = FALSE
 * )
 */
class PageTitleDisplayExtender extends DisplayExtenderPluginBase {

  /**
   * Provide a form to edit options for this plugin.
   */
  public function defineOptionsAlter(&$options) {
    $options['page_title'] =  array(
      'contains' => array(
        'title' => array('default' => ''),
        'append_site_name' => array('default' => TRUE),
      )
    );
  }

  /**
   * Provide a form to edit options for this plugin.
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {

    if ($form_state->get('section') == 'page_title') {
      $form['#title'] .= t('The page title for this display');
      $page_title = $this->getPageTitleValues();

      $form['page_title']['#type'] = 'container';
      $form['page_title']['#tree'] = TRUE;
      $form['page_title']['title'] = array(
        '#title' => $this->t('Page title'),
        '#type' => 'textfield',
        '#description' => $this->t('Let this empty to keep the views title as the page title'),
        '#default_value' => $page_title['title'],
      );

      $form['page_title']['append_site_name'] = array(
        '#title' => $this->t('Append the site name to the page title'),
        '#type' => 'checkbox',
        '#default_value' => isset($page_title['append_site_name']) ? $page_title['append_site_name'] : TRUE,
      );
    }
  }

  /**
   * Validate the options form.
   */
  public function validateOptionsForm(&$form, FormStateInterface $form_state) { }

  /**
   * Handle any special handling on the validate form.
   */
  public function submitOptionsForm(&$form, FormStateInterface $form_state) {
    if ($form_state->get('section') == 'page_title') {
      $page_title = $form_state->getValue('page_title');
      $this->options['page_title'] = $page_title;
    }
  }

  /**
   * Set up any variables on the view prior to execution.
   */
  public function preExecute() { }

  /**
   * Inject anything into the query that the display_extender handler needs.
   */
  public function query() { }

  /**
   * Provide the default summary for options in the views UI.
   *
   * This output is returned as an array.
   */
  public function optionsSummary(&$categories, &$options) {
    $categories['page_title'] = array(
      'title' => t('Page title'),
      'column' => 'second',
    );
    $page_title = $this->hasPageTitle() ? $this->getPageTitleValues() : FALSE;
    $options['page_title'] = array(
      'category' => 'page_title',
      'title' => t('Page title'),
      'value' => $page_title ? $page_title['title'] : t('Using views title'),
    );
  }

  /**
   * Static member function to list which sections are defaultable
   * and what items each section contains.
   */
  public function defaultableSections(&$sections, $section = NULL) { }

  /**
   * Identify whether or not the current display has custom meta tags defined.
   */
  public function hasPageTitle() {
    $page_title = $this->getPageTitleValues();
    return !empty($page_title['title']);
  }

  /**
   * Get the Page title configuration for this display.
   *
   * @return array
   *   The page title values, keys by language (default LANGUAGE_NONE).
   */
  public function getPageTitleValues() {
    $page_title = $this->options['page_title'];

    return $page_title;
  }
}
